@@ -79,13 +79,25 @@ Resolver::Resolver (const ResPool & pool)
     : _pool(pool)
     , _satResolver(NULL)
     , _poolchanged(_pool.serial() )
-    , _upgradeMode		(false)
-    , _updateMode		(false)
-    , _verifying		(false)
-    , _onlyRequires		( ZConfig::instance().solver_onlyRequires() )
-    , _solveSrcPackages		( false )
-    , _cleandepsOnRemove	( ZConfig::instance().solver_cleandepsOnRemove() )
-    , _ignoreAlreadyRecommended	( true )
+    , _upgradeMode              ( false )
+    , _updateMode               ( false )
+    , _verifying                ( false )
+    , _onlyRequires             ( ZConfig::instance().solver_onlyRequires() )
+    , _solveSrcPackages         ( false )
+    , _cleandepsOnRemove        ( ZConfig::instance().solver_cleandepsOnRemove() )
+    , _ignoreAlreadyRecommended ( true )
+    , _applyDefault_focus                ( true )
+    , _applyDefault_forceResolve         ( true )
+    , _applyDefault_cleandepsOnRemove    ( true )
+    , _applyDefault_onlyRequires         ( true )
+    , _applyDefault_allowDowngrade       ( true )
+    , _applyDefault_allowNameChange      ( true )
+    , _applyDefault_allowArchChange      ( true )
+    , _applyDefault_allowVendorChange    ( true )
+    , _applyDefault_dupAllowDowngrade    ( true )
+    , _applyDefault_dupAllowNameChange   ( true )
+    , _applyDefault_dupAllowArchChange   ( true )
+    , _applyDefault_dupAllowVendorChange ( true )
 {
     sat::Pool satPool( sat::Pool::instance() );
     _satResolver = new SATResolver(_pool, satPool.get());
@@ -100,46 +112,75 @@ Resolver::~Resolver()
 sat::detail::CSolver * Resolver::get() const
 { return _satResolver->get(); }
 
+
+void Resolver::setDefaultSolverFlags( bool all_r )
+{
+  MIL << "setDefaultSolverFlags all=" << all_r << endl;
+
+  if ( all_r || _applyDefault_focus ) setFocus( ResolverFocus::Default );
+
+#define ZOLV_FLAG_DEFAULT( ZSETTER, ZGETTER )        \
+  if ( all_r || _applyDefault_##ZGETTER ) ZSETTER( indeterminate )
+
+  ZOLV_FLAG_DEFAULT( setForceResolve         ,forceResolve         );
+  ZOLV_FLAG_DEFAULT( setCleandepsOnRemove    ,cleandepsOnRemove    );
+  ZOLV_FLAG_DEFAULT( setOnlyRequires         ,onlyRequires         );
+  ZOLV_FLAG_DEFAULT( setAllowDowngrade       ,allowDowngrade       );
+  ZOLV_FLAG_DEFAULT( setAllowNameChange      ,allowNameChange      );
+  ZOLV_FLAG_DEFAULT( setAllowArchChange      ,allowArchChange      );
+  ZOLV_FLAG_DEFAULT( setAllowVendorChange    ,allowVendorChange    );
+  ZOLV_FLAG_DEFAULT( dupSetAllowDowngrade    ,dupAllowDowngrade    );
+  ZOLV_FLAG_DEFAULT( dupSetAllowNameChange   ,dupAllowNameChange   );
+  ZOLV_FLAG_DEFAULT( dupSetAllowArchChange   ,dupAllowArchChange   );
+  ZOLV_FLAG_DEFAULT( dupSetAllowVendorChange ,dupAllowVendorChange );
+#undef ZOLV_FLAG_TRIBOOL
+}
 //---------------------------------------------------------------------------
 // forward flags too SATResolver
-
-void Resolver::setFocus( ResolverFocus focus_r )	{ _satResolver->_focus = ( focus_r == ResolverFocus::Default ) ? ZConfig::instance().solver_focus() : focus_r; }
+void Resolver::setFocus( ResolverFocus focus_r )	{
+  _applyDefault_focus = ( focus_r == ResolverFocus::Default );
+  _satResolver->_focus = _applyDefault_focus ? ZConfig::instance().solver_focus() : focus_r;
+}
 ResolverFocus Resolver::focus() const			{ return _satResolver->_focus; }
 
-#define ZOLV_FLAG_TRIBOOL( ZSETTER, ZGETTER, ZVARNAME, ZVARDEFAULT )			\
+#define ZOLV_FLAG_TRIBOOL( ZSETTER, ZGETTER, ZVARDEFAULT, ZVARNAME )			\
     void Resolver::ZSETTER( TriBool state_r )						\
-    { _satResolver->ZVARNAME = indeterminate(state_r) ? ZVARDEFAULT : bool(state_r); }	\
+    { _applyDefault_##ZGETTER = indeterminate(state_r);					\
+      bool newval = _applyDefault_##ZGETTER ? ZVARDEFAULT : bool(state_r);		\
+      if ( ZVARNAME != newval ) {							\
+        DBG << #ZGETTER << ": changed from " << (bool)ZVARNAME << " to " << newval << endl;\
+        ZVARNAME = newval;								\
+      }											\
+    }											\
     bool Resolver::ZGETTER() const							\
-    { return _satResolver->ZVARNAME; }							\
+    { return ZVARNAME; }								\
+
+// Flags stored here follow the naming convention,...
+// TODO: But why do we need them here? Probably too many layers and they can
+// go to _satResolver too.
+#define ZOLV_FLAG_LOCALTB( ZSETTER, ZGETTER, ZVARDEFAULT )				\
+    ZOLV_FLAG_TRIBOOL( ZSETTER, ZGETTER, ZVARDEFAULT, _##ZGETTER )
+// Flags down in _satResolver don't (yet).
+#define ZOLV_FLAG_SATSOLV( ZSETTER, ZGETTER, ZVARDEFAULT, ZVARNAME )			\
+    ZOLV_FLAG_TRIBOOL( ZSETTER, ZGETTER, ZVARDEFAULT, _satResolver->ZVARNAME )
 
 // NOTE: ZVARDEFAULT must be in sync with SATResolver ctor
-ZOLV_FLAG_TRIBOOL( setForceResolve,		forceResolve,		_allowuninstall,	false )
-
-ZOLV_FLAG_TRIBOOL( setAllowDowngrade,		allowDowngrade,		_allowdowngrade,	false )
-ZOLV_FLAG_TRIBOOL( setAllowNameChange,		allowNameChange,	_allownamechange,	true )	// bsc#1071466
-ZOLV_FLAG_TRIBOOL( setAllowArchChange,		allowArchChange,	_allowarchchange,	false )
-ZOLV_FLAG_TRIBOOL( setAllowVendorChange,	allowVendorChange,	_allowvendorchange,	ZConfig::instance().solver_allowVendorChange() )
-
-ZOLV_FLAG_TRIBOOL( dupSetAllowDowngrade,	dupAllowDowngrade,	_dup_allowdowngrade,	ZConfig::instance().solver_dupAllowDowngrade() )
-ZOLV_FLAG_TRIBOOL( dupSetAllowNameChange,	dupAllowNameChange,	_dup_allownamechange,	ZConfig::instance().solver_dupAllowNameChange() )
-ZOLV_FLAG_TRIBOOL( dupSetAllowArchChange,	dupAllowArchChange,	_dup_allowarchchange,	ZConfig::instance().solver_dupAllowArchChange() )
-ZOLV_FLAG_TRIBOOL( dupSetAllowVendorChange,	dupAllowVendorChange,	_dup_allowvendorchange,	ZConfig::instance().solver_dupAllowVendorChange() )
-
+ZOLV_FLAG_SATSOLV( setForceResolve         ,forceResolve         ,false                                             ,_allowuninstall        )
+ZOLV_FLAG_LOCALTB( setCleandepsOnRemove    ,cleandepsOnRemove    ,ZConfig::instance().solver_cleandepsOnRemove()    )
+ZOLV_FLAG_LOCALTB( setOnlyRequires         ,onlyRequires         ,ZConfig::instance().solver_onlyRequires()         )
+ZOLV_FLAG_SATSOLV( setAllowDowngrade       ,allowDowngrade       ,false                                             ,_allowdowngrade        )
+ZOLV_FLAG_SATSOLV( setAllowNameChange      ,allowNameChange      ,true /*bsc#1071466*/                              ,_allownamechange       )
+ZOLV_FLAG_SATSOLV( setAllowArchChange      ,allowArchChange      ,false                                             ,_allowarchchange       )
+ZOLV_FLAG_SATSOLV( setAllowVendorChange    ,allowVendorChange    ,ZConfig::instance().solver_allowVendorChange()    ,_allowvendorchange     )
+ZOLV_FLAG_SATSOLV( dupSetAllowDowngrade    ,dupAllowDowngrade    ,ZConfig::instance().solver_dupAllowDowngrade()    ,_dup_allowdowngrade    )
+ZOLV_FLAG_SATSOLV( dupSetAllowNameChange   ,dupAllowNameChange   ,ZConfig::instance().solver_dupAllowNameChange()   ,_dup_allownamechange   )
+ZOLV_FLAG_SATSOLV( dupSetAllowArchChange   ,dupAllowArchChange   ,ZConfig::instance().solver_dupAllowArchChange()   ,_dup_allowarchchange   )
+ZOLV_FLAG_SATSOLV( dupSetAllowVendorChange ,dupAllowVendorChange ,ZConfig::instance().solver_dupAllowVendorChange() ,_dup_allowvendorchange )
+#undef ZOLV_FLAG_SATSOLV
+#undef ZOLV_FLAG_LOCALTB
 #undef ZOLV_FLAG_TRIBOOL
 //---------------------------------------------------------------------------
 
-void Resolver::setOnlyRequires( TriBool state_r )
-{
-  _onlyRequires = indeterminate(state_r) ? ZConfig::instance().solver_onlyRequires() : bool(state_r);
-}
-
-void Resolver::setCleandepsOnRemove( TriBool state_r )
-{
-  _cleandepsOnRemove = indeterminate(state_r) ? ZConfig::instance().solver_cleandepsOnRemove() : bool(state_r);
-}
-
-//---------------------------------------------------------------------------
-
 ResPool Resolver::pool() const
 { return _pool; }
 
